/v1/interfaces — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Network »

# /v1/interfaces

Contents

- /v1/interfaces
  - GET /v1/interfaces
    - Response status codes
    - Sample session

## GET /v1/interfaces

List all the network interfaces available on the server

### Response status codes

- 200: OK

### Sample session

    curl -i -X GET 'http://localhost:8000/interfaces'

    GET /interfaces HTTP/1.1

    HTTP/1.1 200
    CONNECTION: keep-alive
    CONTENT-LENGTH: 520
    CONTENT-TYPE: application/json
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /v1/interfaces

    [
        {
            "id": "lo0",
            "name": "lo0"
        },
        {
            "id": "gif0",
            "name": "gif0"
        },
        {
            "id": "stf0",
            "name": "stf0"
        },
        {
            "id": "en0",
            "name": "en0"
        },
        {
            "id": "en1",
            "name": "en1"
        },
        {
            "id": "fw0",
            "name": "fw0"
        },
        {
            "id": "en2",
            "name": "en2"
        },
        {
            "id": "p2p0",
            "name": "p2p0"
        },
        {
            "id": "bridge0",
            "name": "bridge0"
        }
    ]

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Network »